@@ -6,7 +6,8 @@ use crate::fs::remove_dir_impl;
 use crate::fs::{
     manually, map_result, remove_dir_unchecked, stat_unchecked, FollowSymlinks, Metadata,
 };
-use std::{fs, io, path::Path};
+use std::path::Path;
+use std::{fs, io};
 
 /// Perform a `rmdirat`-like operation, ensuring that the resolution of the
 /// path never escapes the directory tree rooted at `start`.
